@@ -2,7 +2,7 @@ import os
 import localstack_client.config
 
 # LocalStack version
-VERSION = '0.11.3'
+VERSION = '0.11.6'
 
 # constant to represent the "local" region, i.e., local machine
 REGION_LOCAL = 'local'
@@ -20,6 +20,7 @@ DEFAULT_PORT_WEB_UI = 8080
 
 # host name for localhost
 LOCALHOST = 'localhost'
+LOCALHOST_IP = '127.0.0.1'
 
 # version of the Maven dependency with Java utility code
 LOCALSTACK_MAVEN_VERSION = '0.2.1'
@@ -49,7 +50,7 @@ PATH_USER_REQUEST = '_user_request_'
 
 # name of LocalStack Docker image
 DOCKER_IMAGE_NAME = 'localstack/localstack'
-DOCKER_IMAGE_NAME_LIGHT = 'localstack/localstack-light'
+DOCKER_IMAGE_NAME_FULL = 'localstack/localstack-full'
 
 # backdoor API path used to retrieve or update config variables
 CONFIG_UPDATE_PATH = '/?_config_'
@@ -73,11 +74,12 @@ LAMBDA_TEST_ROLE = 'arn:aws:iam::%s:role/lambda-test-role' % TEST_AWS_ACCOUNT_ID
 
 # installation constants
 ELASTICSEARCH_URLS = {
+    '7.7.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.7.0-linux-x86_64.tar.gz',
     '7.4.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.4.0-linux-x86_64.tar.gz',
     '7.1.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.1.0-linux-x86_64.tar.gz',
     '6.7.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-6.7.0.zip'
 }
-ELASTICSEARCH_DEFAULT_VERSION = '7.1.0'
+ELASTICSEARCH_DEFAULT_VERSION = '7.7.0'
 # See https://docs.aws.amazon.com/ja_jp/elasticsearch-service/latest/developerguide/aes-supported-plugins.html
 ELASTICSEARCH_PLUGIN_LIST = ['analysis-icu', 'ingest-attachment', 'analysis-kuromoji',
  'mapper-murmur3', 'mapper-size', 'analysis-phonetic', 'analysis-smartcn', 'analysis-stempel', 'analysis-ukrainian']
@@ -99,11 +101,17 @@ API_ENDPOINT = os.environ.get('API_ENDPOINT') or 'https://api.localstack.cloud/v
 LOCALSTACK_WEB_PROCESS = 'LOCALSTACK_WEB_PROCESS'
 LOCALSTACK_INFRA_PROCESS = 'LOCALSTACK_INFRA_PROCESS'
 
-# Hardcoded AWS account ID used by moto
+# hardcoded AWS account ID used by moto
 MOTO_ACCOUNT_ID = TEST_AWS_ACCOUNT_ID
 
 # default AWS region us-east-1
 AWS_REGION_US_EAST_1 = 'us-east-1'
 
-# Default lambda registry
+# default lambda registry
 DEFAULT_LAMBDA_CONTAINER_REGISTRY = 'lambci/lambda'
+
+# environment variable to override max pool connections
+try:
+    MAX_POOL_CONNECTIONS = int(os.environ['MAX_POOL_CONNECTIONS'])
+except Exception:
+    MAX_POOL_CONNECTIONS = 150
